PolitoApi class

Constructors

PolitoApi({Dio? dio, String? token})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

basicLogin(LoginRequest request) Future<String?>
logout() Future<void>
me() Future<StudentData?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setToken(String token) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited